@@ -12,7 +12,9 @@
  *	  (using the "get_surface" functions).
  */
 
+#ifdef RSVG
 #include <librsvg/rsvg.h>
+#endif
 #include <png.h>
 
 #include "icon.h"
@@ -95,18 +97,24 @@ static cairo_surface_t *get_png_icon(const char *filename)
 	return image;
 }
 
+#ifdef RSVG
 static cairo_surface_t *get_svg_icon(const char *filename, int size)
 {
 	cairo_surface_t *surface;
 	cairo_t *cr;
 	RsvgHandle *svg;
 	GError *err = NULL;
+#if LIBRSVG_CHECK_VERSION(2, 52, 0)
 	RsvgRectangle viewport = {
 		.x = 0,
 		.y = 0,
 		.width = size,
 		.height = size,
 	};
+#else
+	RsvgDimensionData  dimensions;
+	double scale, ratio;
+#endif
 
 	svg = rsvg_handle_new_from_file(filename, &err);
 	if (err) {
@@ -116,6 +124,7 @@ static cairo_surface_t *get_svg_icon(const char *filename, int size)
 		return NULL;
 	}
 
+#if LIBRSVG_CHECK_VERSION(2, 52, 0)
 	surface = cairo_image_surface_create(CAIRO_FORMAT_ARGB32, size, size);
 	cr = cairo_create(surface);
 
@@ -126,11 +135,35 @@ static cairo_surface_t *get_svg_icon(const char *filename, int size)
 		g_error_free(err);
 		return NULL;
 	}
+#else
+	rsvg_handle_get_dimensions(svg, &dimensions);
+	if (dimensions.width == dimensions.height) {
+		surface = cairo_image_surface_create(CAIRO_FORMAT_ARGB32,
+						     size, size);
+		cr = cairo_create(surface);
+		cairo_scale(cr, (double)size / dimensions.width,
+			    (double)size / dimensions.height);
+	} else if (dimensions.width > dimensions.height) {
+		ratio = (double)dimensions.width / dimensions.height;
+		scale = (double)size / dimensions.width;
+		surface = cairo_image_surface_create(CAIRO_FORMAT_ARGB32, size, size / ratio);
+		cr = cairo_create(surface);
+		cairo_scale(cr, scale, scale);
+	} else {
+		ratio = (double)dimensions.width / dimensions.height;
+		scale = (double)size / dimensions.height;
+		surface = cairo_image_surface_create(CAIRO_FORMAT_ARGB32, size * ratio, size);
+		cr = cairo_create(surface);
+		cairo_scale(cr, scale, scale);
+	}
+	rsvg_handle_render_cairo(svg, cr);
+#endif
 	cairo_destroy(cr);
 	g_object_unref(svg);
 
 	return surface;
 }
+#endif
 
 void icon_set_name(const char *name)
 {
@@ -153,8 +186,10 @@ cairo_surface_t *load_cairo_icon(const char *path, int icon_size)
 {
 	if (strstr(path, ".png"))
 		return get_png_icon(path);
+#ifdef RSVG
 	else if (strstr(path, ".svg"))
 		return get_svg_icon(path, icon_size);
+#endif
 	else if (strstr(path, ".xpm"))
 		return get_xpm_icon(path);
 	return NULL;
