@@ -226,7 +226,7 @@ void ui_get_screen_res(int *x0, int *y0, int *width, int *height, int monitor)
 
 monitor_selected:
 	if (!ci)
-		die("connection could be established to monitor");
+		die("connection cannot be established to monitor; this may be due to missing packages such as xrandr, x11-xserver-utils or mesa-utils");
 	*x0 = ci->x;
 	*y0 = ci->y;
 	*width = ci->width;
@@ -451,55 +451,59 @@ void ui_draw_rectangle(double x, double y, double w, double h, double radius, do
 	}
 }
 
-void ui_draw_rectangle_gradient(double x, double y, double w, double h, double radius, double line_width, int fill, double *top_rgba, double *bot_rgba, enum alignment align) 
+void ui_draw_rectangle_gradient(double x, double y, double w, double h,
+				double radius, double line_width, int fill,
+				double *top_rgba, double *bot_rgba,
+				enum alignment align)
 {
 	cairo_pattern_t *pat1;
-	switch(align) {
-		case LEFT:
-			pat1 = cairo_pattern_create_linear(x, y, x + w, y);
-			cairo_pattern_add_color_stop_rgba(pat1, 0, top_rgba[0], top_rgba[1], top_rgba[2], top_rgba[3]);
-			cairo_pattern_add_color_stop_rgba(pat1, 50, bot_rgba[0], bot_rgba[1], bot_rgba[2], bot_rgba[3]);
-			break;
-		case RIGHT:
-			pat1 = cairo_pattern_create_linear(x, y, x + w, y);
-			cairo_pattern_add_color_stop_rgba(pat1, 0, bot_rgba[0], bot_rgba[1], bot_rgba[2], bot_rgba[3]);
-			cairo_pattern_add_color_stop_rgba(pat1, 50, top_rgba[0], top_rgba[1], top_rgba[2], top_rgba[3]);
-			break;
-		case TOP:
-			pat1 = cairo_pattern_create_linear(x, y, x, y + h);
-			cairo_pattern_add_color_stop_rgba(pat1, 0, top_rgba[0], top_rgba[1], top_rgba[2], top_rgba[3]);
-			cairo_pattern_add_color_stop_rgba(pat1, 50, bot_rgba[0], bot_rgba[1], bot_rgba[2], bot_rgba[3]);
-			break;
-		case BOTTOM:
-			pat1 = cairo_pattern_create_linear(x, y, x, y + h);
-			cairo_pattern_add_color_stop_rgba(pat1, 0, bot_rgba[0], bot_rgba[1], bot_rgba[2], bot_rgba[3]);
-			cairo_pattern_add_color_stop_rgba(pat1, 50, top_rgba[0], top_rgba[1], top_rgba[2], top_rgba[3]);
-			break;
-		case TOP_LEFT:
-			pat1 = cairo_pattern_create_linear(x, y, x + w, y + h);
-			cairo_pattern_add_color_stop_rgba(pat1, 0, top_rgba[0], top_rgba[1], top_rgba[2], top_rgba[3]);
-			cairo_pattern_add_color_stop_rgba(pat1, 50, bot_rgba[0], bot_rgba[1], bot_rgba[2], bot_rgba[3]);
-			break;
-		case TOP_RIGHT:
-			pat1 = cairo_pattern_create_linear(x + w, y, x, y + h);
-			cairo_pattern_add_color_stop_rgba(pat1, 0, top_rgba[0], top_rgba[1], top_rgba[2], top_rgba[3]);
-			cairo_pattern_add_color_stop_rgba(pat1, 50, bot_rgba[0], bot_rgba[1], bot_rgba[2], bot_rgba[3]);
-			break;
-		case BOTTOM_LEFT:
-			pat1 = cairo_pattern_create_linear(x + w, y, x, y + h);
-			cairo_pattern_add_color_stop_rgba(pat1, 0, bot_rgba[0], bot_rgba[1], bot_rgba[2], bot_rgba[3]);
-			cairo_pattern_add_color_stop_rgba(pat1, 50, top_rgba[0], top_rgba[1], top_rgba[2], top_rgba[3]);
-			break;
-		case BOTTOM_RIGHT:
-			pat1 = cairo_pattern_create_linear(x, y, x + w, y + h);
-			cairo_pattern_add_color_stop_rgba(pat1, 0, bot_rgba[0], bot_rgba[1], bot_rgba[2], bot_rgba[3]);
-			cairo_pattern_add_color_stop_rgba(pat1, 50, top_rgba[0], top_rgba[1], top_rgba[2], top_rgba[3]);
-			break;
-		default:
-			pat1 = cairo_pattern_create_linear(x, y, x, y + h);
-			cairo_pattern_add_color_stop_rgba(pat1, 0, top_rgba[0], top_rgba[1], top_rgba[2], top_rgba[3]);
-			cairo_pattern_add_color_stop_rgba(pat1, 50, bot_rgba[0], bot_rgba[1], bot_rgba[2], bot_rgba[3]);
-			break;
+
+	switch (align) {
+	case LEFT:
+		pat1 = cairo_pattern_create_linear(x, y, x + w, y);
+		cairo_pattern_add_color_stop_rgba(pat1, 0, top_rgba[0], top_rgba[1], top_rgba[2], top_rgba[3]);
+		cairo_pattern_add_color_stop_rgba(pat1, 50, bot_rgba[0], bot_rgba[1], bot_rgba[2], bot_rgba[3]);
+		break;
+	case RIGHT:
+		pat1 = cairo_pattern_create_linear(x, y, x + w, y);
+		cairo_pattern_add_color_stop_rgba(pat1, 0, bot_rgba[0], bot_rgba[1], bot_rgba[2], bot_rgba[3]);
+		cairo_pattern_add_color_stop_rgba(pat1, 50, top_rgba[0], top_rgba[1], top_rgba[2], top_rgba[3]);
+		break;
+	case TOP:
+		pat1 = cairo_pattern_create_linear(x, y, x, y + h);
+		cairo_pattern_add_color_stop_rgba(pat1, 0, top_rgba[0], top_rgba[1], top_rgba[2], top_rgba[3]);
+		cairo_pattern_add_color_stop_rgba(pat1, 50, bot_rgba[0], bot_rgba[1], bot_rgba[2], bot_rgba[3]);
+		break;
+	case BOTTOM:
+		pat1 = cairo_pattern_create_linear(x, y, x, y + h);
+		cairo_pattern_add_color_stop_rgba(pat1, 0, bot_rgba[0], bot_rgba[1], bot_rgba[2], bot_rgba[3]);
+		cairo_pattern_add_color_stop_rgba(pat1, 50, top_rgba[0], top_rgba[1], top_rgba[2], top_rgba[3]);
+		break;
+	case TOP_LEFT:
+		pat1 = cairo_pattern_create_linear(x, y, x + w, y + h);
+		cairo_pattern_add_color_stop_rgba(pat1, 0, top_rgba[0], top_rgba[1], top_rgba[2], top_rgba[3]);
+		cairo_pattern_add_color_stop_rgba(pat1, 50, bot_rgba[0], bot_rgba[1], bot_rgba[2], bot_rgba[3]);
+		break;
+	case TOP_RIGHT:
+		pat1 = cairo_pattern_create_linear(x + w, y, x, y + h);
+		cairo_pattern_add_color_stop_rgba(pat1, 0, top_rgba[0], top_rgba[1], top_rgba[2], top_rgba[3]);
+		cairo_pattern_add_color_stop_rgba(pat1, 50, bot_rgba[0], bot_rgba[1], bot_rgba[2], bot_rgba[3]);
+		break;
+	case BOTTOM_LEFT:
+		pat1 = cairo_pattern_create_linear(x + w, y, x, y + h);
+		cairo_pattern_add_color_stop_rgba(pat1, 0, bot_rgba[0], bot_rgba[1], bot_rgba[2], bot_rgba[3]);
+		cairo_pattern_add_color_stop_rgba(pat1, 50, top_rgba[0], top_rgba[1], top_rgba[2], top_rgba[3]);
+		break;
+	case BOTTOM_RIGHT:
+		pat1 = cairo_pattern_create_linear(x, y, x + w, y + h);
+		cairo_pattern_add_color_stop_rgba(pat1, 0, bot_rgba[0], bot_rgba[1], bot_rgba[2], bot_rgba[3]);
+		cairo_pattern_add_color_stop_rgba(pat1, 50, top_rgba[0], top_rgba[1], top_rgba[2], top_rgba[3]);
+		break;
+	default:
+		pat1 = cairo_pattern_create_linear(x, y, x, y + h);
+		cairo_pattern_add_color_stop_rgba(pat1, 0, top_rgba[0], top_rgba[1], top_rgba[2], top_rgba[3]);
+		cairo_pattern_add_color_stop_rgba(pat1, 50, bot_rgba[0], bot_rgba[1], bot_rgba[2], bot_rgba[3]);
+		break;
 	}
 
 	x += line_width / 2;
@@ -517,7 +521,6 @@ void ui_draw_rectangle_gradient(double x, double y, double w, double h, double r
 		cairo_arc(ui->w[ui->cur].c, x + radius, y + h - radius, radius, 90 * deg, 180 * deg);
 		cairo_arc(ui->w[ui->cur].c, x + radius, y + radius, radius, 180 * deg, 270 * deg);
 		cairo_close_path(ui->w[ui->cur].c);
-		//set_rgba(test);
 		if (fill) {
 			cairo_set_source(ui->w[ui->cur].c, pat1);
 			cairo_set_line_width(ui->w[ui->cur].c, 0.0);
@@ -527,7 +530,6 @@ void ui_draw_rectangle_gradient(double x, double y, double w, double h, double r
 		}
 		cairo_stroke(ui->w[ui->cur].c);
 	} else {
-		//set_rgba(test);
 		cairo_set_line_width(ui->w[ui->cur].c, line_width);
 		cairo_rectangle(ui->w[ui->cur].c, x, y, w, h);
 		if (fill) {
